@@ -1,3 +1,5 @@
+from warnings import warn
+
 from gym.envs.registration import register
 
 from gym_robotics.core import GoalEnv
@@ -8,6 +10,14 @@ __version__ = _version.get_versions()["version"]
 
 
 def register_robotics_envs():
+
+    # gym_robotics package deprecated in favor of gymnasium_robotics
+    warn(
+        "The package name gym_robotics has been deprecated in favor of gymnasium_robotics. Please uninstall gym_robotics and install gymnasium_robotics with `pip install gymnasium_robotics`. Future releases will be maintained under the new package name gymnasium_robotics.",
+        DeprecationWarning,
+        stacklevel=2,
+    )
+
     def _merge(a, b):
         a.update(b)
         return a
@@ -137,19 +147,6 @@ def register_robotics_envs():
             max_episode_steps=100,
         )
 
-        register(
-            id=f"HandManipulateBlockRotateZ{suffix}-v1",
-            entry_point="gym_robotics.envs:MujocoHandBlockEnv",
-            kwargs=_merge(
-                {
-                    "target_position": "ignore",
-                    "target_rotation": "z",
-                },
-                kwargs,
-            ),
-            max_episode_steps=100,
-        )
-
         register(
             id=f"HandManipulateBlockRotateZ_BooleanTouchSensors{suffix}-v1",
             entry_point="gym_robotics.envs:MujocoHandBlockTouchSensorsEnv",
